@@ -368,7 +368,8 @@ if (isset($_POST['max_url']) && ($_POST['max_url'] > -1))
 	}
 	if ($http_cnt >= $_POST['max_url'])
 	{
-		header("Location: $redirect");
+		if (isset($redirect) && ($redirect != ""))
+			header("Location: $redirect");
 		exit;
 	}
 }
@@ -381,6 +382,25 @@ if (isset($_FILES))	{
 		$_POST['allowed_file_ext'] = str_replace(array(".", " "), "", $_POST['allowed_file_ext']);
 		$allowed_file_ext = explode(",", $_POST['allowed_file_ext']);
 	}
+	//////////////////////////////////////////////////////
+	if ((isset($_POST['image_width']) && ($_POST['image_width'] != "")) || (isset($_POST['image_height']) && ($_POST['image_height'] != "")))	{
+		include("image_processing.php");
+		$process_images = true;
+		$image_ext = array("jpg", "gif", "png", "jpeg");
+		if (isset($_POST['image_width']) && ($_POST['image_width'] != ""))
+			$max_width = $_POST['image_width'];
+		else
+			$max_width = 1000000;
+		if (isset($_POST['image_height']) && ($_POST['image_height'] != ""))
+			$max_height = $_POST['image_height'];
+		else
+			$max_height = 1000000;
+		if (isset($_POST['preserve_aspect_ratio']) && ($_POST['preserve_aspect_ratio'] != ""))
+			$preserve_aspect_ratio = $_POST['preserve_aspect_ratio'];
+		else
+			$preserve_aspect_ratio = 1;
+	}
+	//////////////////////////////////////////////////////
 	
 	foreach($_FILES as $file_key => $file)	{
 		if (basename($file["name"] == ""))	{
@@ -432,6 +452,15 @@ if (isset($_FILES))	{
 			$err_msg = "There was an error uploading your file.  Please try again.";
 			DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
 		}
+		///////////////////////////////////////////
+		if (($process_images === true) && in_array(strtolower($ext), $image_ext))	{
+			if (resize_image($target_file, $max_width, $max_height, $target_file, 1, $preserve_aspect_ratio) != 1)	{
+				$err_code = "img_resize";
+				$err_msg = "There was an error resizing your image.  Please try again.";
+				DisplayError($redirect_err_to_src, $err_msg, $err_code, $go_back);
+			}
+		}
+		///////////////////////////////////////////
 	}
 }
 
@@ -844,16 +873,19 @@ if (isset($_FILES) && ($_POST["store_uploads_instead"] < 1))	{
 
 /////////////////////////////////////////////////////////////////////////
 // If data stored in table, then pass along last id to next page.
-if (isset($table_name) && ($table_name != ""))
+if (isset($redirect) && ($redirect != ""))
 {
-	if (strpos($redirect, "?") > 0)
-		$redirect .= "&last_id=" . $last_id;
-	else
-		$redirect .= "?last_id=" . $last_id;
+	if (isset($table_name) && ($table_name != ""))
+	{
+		if (strpos($redirect, "?") > 0)
+			$redirect .= "&last_id=" . $last_id;
+		else
+			$redirect .= "?last_id=" . $last_id;
+	}
+		
+	// Go to desired next page.
+	header("Location: $redirect");
 }
-	
-// Go to desired next page.
-header("Location: $redirect");
 exit;
 
 /////////////////////////////////////////////////////////////////////////
