@@ -1,7 +1,7 @@
 <?php
 ////////////////////////////////////////////////////////////////////////
 // Breeze Website Builder
-// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
+// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
 // For licensing, see license.txt.
 // Created: 10/26/2009		ELL
 // Modified: 1/6/2010		ELL
@@ -21,24 +21,34 @@
 // Added table prefix handling.  Added references to CSS folder configurations.
 // Revised: 7/21/2013	ELL
 // Added background opacity.
+// Revised: 3/10/2015	ELL
+// Converted deprecated font stretch to letter spacing.
+// Revised: 4/5/2015	ELL
+// Added font size units.
+// Converted save operation to AJAX.
+// Revamped preview to show actual popup page.
+// Revised: 10/3/2016	ELL
+// Add display = block to .top_level_ax to cause click area to cover full button instead of just text.
 //
 	include ("check_session.php");
 	include ("lib/copy_table.php");
+	include("lib/build_css_string.php");
 		
-	$submit = $_POST['submit'];
+	$operation = $_POST['operation'];
 	$menu = $_REQUEST['menu'];
-	$suffix = substr($menu, 4);
+	$tmp = str_replace("_mobile", "", $menu);
+	$suffix = substr($tmp, 4);
+	$class_table = $menu . "_classes";
 	
-	if ($submit == "Preview")
+	if ($operation == "Preview")
 	{
 		$site_css_table = "menu_styles_preview";
-		$css_file = "menu_preview.css";
+		$css_file = "menu_styles_preview.css";
 		
-		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . $site_css_table . "menu_styles_preview";
+		$query = "TRUNCATE TABLE " . BWB_TABLE_PREFIX . $site_css_table;
 		$cnt = $bwb_dbh->exec($query);
-		
 		$src_table = $menu . "_css";
-		copy_table(BWB_TABLE_PREFIX . $src_table, BWB_TABLE_PREFIX . "menu_styles_preview", $bwb_dbh, $bwb_database);
+		copy_table(BWB_TABLE_PREFIX . $src_table, BWB_TABLE_PREFIX . $site_css_table, $bwb_dbh, $bwb_database);
 	}
 	else
 	{
@@ -50,10 +60,14 @@
 	else $top_level_font = "-not selected-";
 	if (is_numeric($_POST["top_level_font_size"])) $top_level_font_size = $_POST["top_level_font_size"];
 	else $top_level_font_size = -1;
+	if (isset($_POST["top_level_font_size_units"])) $top_level_font_size_units = $_POST["top_level_font_size_units"];
+	else $top_level_font_size_units = "px";
 	if (isset($_POST["top_level_weight"])) $top_level_weight = $_POST["top_level_weight"];
 	else $top_level_weight = "-not selected-";
-	if (isset($_POST["top_level_font_stretch"])) $top_level_font_stretch = $_POST["top_level_font_stretch"];
-	else $top_level_font_stretch = "-not selected-";
+	if (isset($_POST["top_level_letter_spacing"])) $top_level_letter_spacing = $_POST["top_level_letter_spacing"];
+	else $top_level_letter_spacing = "-not selected-";
+	if (isset($_POST["top_level_letter_spacing_units"])) $top_level_letter_spacing_units = $_POST["top_level_letter_spacing_units"];
+	else $top_level_letter_spacing_units = "-not selected-";	
 	if (is_numeric($_POST["top_level_italic"])) $top_level_italic = $_POST["top_level_italic"];
 	else $top_level_italic = 0;
 	if (is_numeric($_POST["top_level_underline"])) $top_level_underline = $_POST["top_level_underline"];
@@ -83,10 +97,14 @@
 	else $sub_level_1_font = "-not selected-";
 	if (is_numeric($_POST["sub_level_1_font_size"])) $sub_level_1_font_size = $_POST["sub_level_1_font_size"];
 	else $sub_level_1_font_size = -1;
+	if (isset($_POST["sub_level_1_font_size_units"])) $sub_level_1_font_size_units = $_POST["sub_level_1_font_size_units"];
+	else $sub_level_1_font_size_units = "px";
 	if (isset($_POST["sub_level_1_weight"])) $sub_level_1_weight = $_POST["sub_level_1_weight"];
 	else $sub_level_1_weight = "-not selected-";
-	if (isset($_POST["sub_level_1_font_stretch"])) $sub_level_1_font_stretch = $_POST["sub_level_1_font_stretch"];
-	else $sub_level_1_font_stretch = "-not selected-";
+	if (isset($_POST["sub_level_1_letter_spacing"])) $sub_level_1_letter_spacing = $_POST["sub_level_1_letter_spacing"];
+	else $sub_level_1_letter_spacing = "-not selected-";
+	if (isset($_POST["sub_level_1_letter_spacing_units"])) $sub_level_1_letter_spacing_units = $_POST["sub_level_1_letter_spacing_units"];
+	else $sub_level_1_letter_spacing_units = "-not selected-";	
 	if (is_numeric($_POST["sub_level_1_italic"])) $sub_level_1_italic = $_POST["sub_level_1_italic"];
 	else $sub_level_1_italic = 0;
 	if (is_numeric($_POST["sub_level_1_underline"])) $sub_level_1_underline = $_POST["sub_level_1_underline"];
@@ -116,10 +134,14 @@
 	else $sub_level_2_font = "-not selected-";
 	if (is_numeric($_POST["sub_level_2_font_size"])) $sub_level_2_font_size = $_POST["sub_level_2_font_size"];
 	else $sub_level_2_font_size = -1;
+	if (isset($_POST["sub_level_2_font_size_units"])) $sub_level_2_font_size_units = $_POST["sub_level_2_font_size_units"];
+	else $sub_level_2_font_size_units = "px";
 	if (isset($_POST["sub_level_2_weight"])) $sub_level_2_weight = $_POST["sub_level_2_weight"];
 	else $sub_level_2_weight = "-not selected-";
-	if (isset($_POST["sub_level_2_font_stretch"])) $sub_level_2_font_stretch = $_POST["sub_level_2_font_stretch"];
-	else $sub_level_2_font_stretch = "-not selected-";
+	if (isset($_POST["sub_level_2_letter_spacing"])) $sub_level_2_letter_spacing = $_POST["sub_level_2_letter_spacing"];
+	else $sub_level_2_letter_spacing = "-not selected-";
+	if (isset($_POST["sub_level_2_letter_spacing_units"])) $sub_level_2_letter_spacing_units = $_POST["sub_level_2_letter_spacing_units"];
+	else $sub_level_2_letter_spacing_units = "-not selected-";	
 	if (is_numeric($_POST["sub_level_2_italic"])) $sub_level_2_italic = $_POST["sub_level_2_italic"];
 	else $sub_level_2_italic = 0;
 	if (is_numeric($_POST["sub_level_2_underline"])) $sub_level_2_underline = $_POST["sub_level_2_underline"];
@@ -227,12 +249,12 @@
 	else $sub_level_item_border_right = 0;
 	$sub_level_item_border_sides = ($sub_level_item_border_top * 8) | ($sub_level_item_border_bottom * 4) | ($sub_level_item_border_left * 2) | $sub_level_item_border_right;
 	
-	if (isset($_POST["top_level_background_opacity"])) $top_level_background_opacity = $_POST["top_level_background_opacity"];
+	if (is_numeric($_POST["top_level_background_opacity"])) $top_level_background_opacity = $_POST["top_level_background_opacity"];
 	else $top_level_background_opacity = -1;
-	if (isset($_POST["sub_level_background_opacity"])) $sub_level_background_opacity = $_POST["sub_level_background_opacity"];
+	if (is_numeric($_POST["sub_level_background_opacity"])) $sub_level_background_opacity = $_POST["sub_level_background_opacity"];
 	else $sub_level_background_opacity = -1;
 		
-	
+
 	///////////////////////////////////////////////////////////////////////////////////////////
 	if (($top_level_underline == 0) && ($top_level_overline == 0) && (top_level_blink == 0))
 		$text_decoration_none = 1;
@@ -243,26 +265,31 @@
 	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $top_level_font . "', font_size=" . $top_level_font_size
-		. ", weight='" . $top_level_weight . "', font_stretch='" . $top_level_font_stretch . "', italic=" . $top_level_italic 
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $top_level_font 
+		. "', font_size=" . $top_level_font_size . ", font_size_units='" . $top_level_font_size_units
+		. "', weight='" . $top_level_weight . "', letter_spacing='" . $top_level_letter_spacing 
+		. "', letter_spacing_units=" . $top_level_letter_spacing_units
+		. ", italic=" . $top_level_italic 
 		. ", underline=" . $top_level_underline . ", overline=" . $top_level_overline . ", blink=" . $top_level_blink
 		. ", oblique=" . $top_level_oblique . ", small_caps=" . $top_level_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $top_level_shadow
 		. ", shadow_color='" . $top_level_shadow_color . "', shadow_x_offset=" . $top_level_shadow_x_offset
 		. ", shadow_y_offset=" . $top_level_shadow_y_offset . ", shadow_blur=" . $top_level_shadow_blur
-		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1 WHERE class='.top_level_a" . $suffix . "'";
+		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1, display='block' WHERE class='.top_level_a" . $suffix . "'";
 	}
 	else
 	{
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_a" . $suffix . "', use_table_data=1, font='" . $top_level_font
-		. "', font_size=" . $top_level_font_size
-		. ", weight='" . $top_level_weight . "', font_stretch='" . $top_level_font_stretch . "', italic=" . $top_level_italic 
+		. "', font_size=" . $top_level_font_size . ", font_size_units='" . $top_level_font_size_units
+		. "', weight='" . $top_level_weight . "', letter_spacing='" . $top_level_letter_spacing 
+		. "', letter_spacing_units=" . $top_level_letter_spacing_units
+		. ", italic=" . $top_level_italic 
 		. ", underline=" . $top_level_underline . ", overline=" . $top_level_overline . ", blink=" . $top_level_blink
 		. ", oblique=" . $top_level_oblique . ", small_caps=" . $top_level_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $top_level_shadow
 		. ", shadow_color='" . $top_level_shadow_color . "', shadow_x_offset=" . $top_level_shadow_x_offset
 		. ", shadow_y_offset=" . $top_level_shadow_y_offset . ", shadow_blur=" . $top_level_shadow_blur
-		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1";
+		. ", text_color='" . $top_level_text_color . "', bkgd_opacity=-1, display='block'";
 	}
 	$cnt = $bwb_dbh->exec($query);
 	
@@ -276,8 +303,11 @@
 	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_1_font . "', font_size=" . $sub_level_1_font_size
-		. ", weight='" . $sub_level_1_weight . "', font_stretch='" . $sub_level_1_font_stretch . "', italic=" . $sub_level_1_italic 
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_1_font 
+		. "', font_size=" . $sub_level_1_font_size . ", font_size_units='" . $sub_level_1_font_size_units
+		. "', weight='" . $sub_level_1_weight . "', letter_spacing='" . $sub_level_1_letter_spacing 
+		. "', letter_spacing_units=" . $sub_level_1_letter_spacing_units
+		. ", italic=" . $sub_level_1_italic 
 		. ", underline=" . $sub_level_1_underline . ", overline=" . $sub_level_1_overline . ", blink=" . $sub_level_1_blink
 		. ", oblique=" . $sub_level_1_oblique . ", small_caps=" . $sub_level_1_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $sub_level_1_shadow
@@ -288,8 +318,10 @@
 	else
 	{
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_1_a" . $suffix . "', use_table_data=1, font='" . $sub_level_1_font
-		. "', font_size=" . $sub_level_1_font_size
-		. ", weight='" . $sub_level_1_weight . "', font_stretch='" . $sub_level_1_font_stretch . "', italic=" . $sub_level_1_italic 
+		. "', font_size=" . $sub_level_1_font_size . ", font_size_units='" . $sub_level_1_font_size_units
+		. "', weight='" . $sub_level_1_weight . "', letter_spacing='" . $sub_level_1_letter_spacing 
+		. "', letter_spacing_units=" . $sub_level_1_letter_spacing_units
+		. ", italic=" . $sub_level_1_italic 
 		. ", underline=" . $sub_level_1_underline . ", overline=" . $sub_level_1_overline . ", blink=" . $sub_level_1_blink
 		. ", oblique=" . $sub_level_1_oblique . ", small_caps=" . $sub_level_1_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $sub_level_1_shadow
@@ -309,8 +341,11 @@
 	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
-		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_2_font . "', font_size=" . $sub_level_2_font_size
-		. ", weight='" . $sub_level_2_weight . "', font_stretch='" . $sub_level_2_font_stretch . "', italic=" . $sub_level_2_italic 
+		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, font='" . $sub_level_2_font 
+		. "', font_size=" . $sub_level_2_font_size . ", font_size_units='" . $sub_level_2_font_size_units
+		. "', weight='" . $sub_level_2_weight . "', letter_spacing='" . $sub_level_2_letter_spacing 
+		. "', letter_spacing_units=" . $sub_level_2_letter_spacing_units
+		. ", italic=" . $sub_level_2_italic 
 		. ", underline=" . $sub_level_2_underline . ", overline=" . $sub_level_2_overline . ", blink=" . $sub_level_2_blink
 		. ", oblique=" . $sub_level_2_oblique . ", small_caps=" . $sub_level_2_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $sub_level_2_shadow
@@ -321,8 +356,10 @@
 	else
 	{
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.sub_level_2_a" . $suffix . "', use_table_data=1, font='" . $sub_level_2_font
-		. "', font_size=" . $sub_level_2_font_size
-		. ", weight='" . $sub_level_2_weight . "', font_stretch='" . $sub_level_2_font_stretch . "', italic=" . $sub_level_2_italic 
+		. "', font_size=" . $sub_level_2_font_size . ", font_size_units='" . $sub_level_2_font_size_units
+		. "', weight='" . $sub_level_2_weight . "', letter_spacing='" . $sub_level_2_letter_spacing 
+		. "', letter_spacing_units=" . $sub_level_2_letter_spacing_units
+		. ", italic=" . $sub_level_2_italic 
 		. ", underline=" . $sub_level_2_underline . ", overline=" . $sub_level_2_overline . ", blink=" . $sub_level_2_blink
 		. ", oblique=" . $sub_level_2_oblique . ", small_caps=" . $sub_level_2_small_caps . ", no_text_decoration=" . $text_decoration_none
 		. ", shadow=" . $sub_level_2_shadow
@@ -409,9 +446,6 @@
 	if ($row_count > 0)
 	{
 		//Update class record.
-//		$query = "UPDATE " . $site_css_table . " SET use_table_data=1, text_color='" . $sub_level_1_text_color_hover . "', bkgd_color='" . $top_level_background_color_hover
-//		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
-//		. "' WHERE class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover'";
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, bkgd_color='" . $top_level_background_color_hover
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
 		. "', border_sides=" . $top_level_item_border_sides
@@ -421,9 +455,6 @@
 	else
 	{
 		//Insert new data into table.
-//		$query = "INSERT INTO " . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover', use_table_data=1, text_color='"
-//		. $sub_level_1_text_color_hover . "', bkgd_color='" . $top_level_background_color_hover
-//		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover . "', z_index=2";
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='ul.nav" . $suffix . " li:hover, .nav" . $suffix . " ul li a:hover', use_table_data=1, bkgd_color='" 
 		. $top_level_background_color_hover
 		. "', border=" . $top_level_item_border_width . ", border_color='" . $top_level_item_border_color_hover
@@ -472,23 +503,18 @@
 	$cnt = $bwb_dbh->exec($query);
 	
 	//////////////////////////////////////////////////////////////////////////////////////////
-//	$query = "SELECT `use_table_data` FROM " . $site_css_table . " WHERE `class` = '.nav" . $suffix . " a:hover'";
 	$query = "SELECT `use_table_data` FROM " . BWB_TABLE_PREFIX . $site_css_table . " WHERE `class` = '.top_level_li" . $suffix . " A:hover'";
 	$result = $bwb_dbh->query($query);
 	$row_count = $result->rowCount();
 	if ($row_count > 0)
 	{
 		//Update class record.
-//		$query = "UPDATE " . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color_hover
-//		. "' WHERE class='.nav" . $suffix . " a:hover'";
 		$query = "UPDATE " . BWB_TABLE_PREFIX . $site_css_table . " SET use_table_data=1, text_color='" . $top_level_text_color_hover
 		. "', bkgd_opacity=-1 WHERE class='.top_level_li" . $suffix . " A:hover'";
 	}
 	else
 	{
 		//Insert new data into table.
-//		$query = "INSERT INTO " . $site_css_table . " SET class='.nav" . $suffix . " a:hover', use_table_data=1, text_color='"
-//		. $top_level_text_color_hover . "'";
 		$query = "INSERT INTO " . BWB_TABLE_PREFIX . $site_css_table . " SET class='.top_level_li" . $suffix . " A:hover', use_table_data=1, text_color='"
 		. $top_level_text_color_hover . "', bkgd_opacity=-1";
 	}
@@ -687,7 +713,7 @@
 
 	/////////////////////////////////////////////
 	// Build string for site.css file /////
-	include("build_css_string.php");
+	$css_string = BuildCSSString(BWB_TABLE_PREFIX . $site_css_table, BWB_TABLE_PREFIX . $class_table, $bwb_dbh, BWB_BASE_DIR, BWB_IMAGE_DIR, BWB_TABLE_PREFIX . "fonts");
 			
 
 	////////////////////////////////////////////////////////
@@ -705,19 +731,15 @@
 	{
 		$bkup_file_name = $file_name . time();
 		if (!rename($file_name, $bkup_file_name))
-			echo "Could not rename $file_name to $bkup_file_name.<br>";
+			echo ADD_PLUGIN_TO_PAGE_COULD_NOT_RENAME_MSG . " $file_name " . TO_WORD ." $bkup_file_name.<br>";
 		@chmod($bkup_file_name, 0644);
 	}
 	
 	// Create file.
-	$fh = fopen($file_name, 'x') or die("Can't create $file_name: $php_errormsg");
+	$fh = fopen($file_name, 'x') or die(UPLOAD_TEMPLATE_CANT_CREATE_ERR . " $file_name: $php_errormsg");
 	$result = (fputs($fh, $css_string));
 	fclose($fh) or die($php_errormsg);
 	@chmod($file_name, 0644);
 	
-	if ($submit == "Preview")
-		header("Location: preview_menu.php?suffix=$suffix&menu_type=0");
-	else
-		header("Location: edit_css_menu_styles.php?menu=$menu");
-		
+	echo 1;
 ?>
